@@ -137,7 +137,7 @@ pango_cairo_fc_font_get_font_face (PangoCairoFont *font)
        * we can't proceed at that point
        */
       if (!cffont->font_face)
-	g_error ("Unable create Cairo font name");
+	g_error ("Unable to create FT2 cairo font face.\nThis means out of memory or a cairo/fontconfig/FreeType bug");
     }
   
   return cffont->font_face;
@@ -163,7 +163,7 @@ pango_cairo_fc_font_get_scaled_font (PangoCairoFont *font)
        * we can't proceed at that point
        */
       if (!cffont->scaled_font)
-	g_error ("Unable create Cairo font");
+	g_error ("Unable to create FT2 cairo scaled font.\nThis means out of memory or a cairo/fontconfig/FreeType bug");
     }
   
   return cffont->scaled_font;
@@ -173,7 +173,7 @@ pango_cairo_fc_font_get_scaled_font (PangoCairoFont *font)
  *    Method implementations    *
  ********************************/
 
-static void
+static gboolean
 pango_cairo_fc_font_install (PangoCairoFont *font,
 			     cairo_t        *cr)
 {
@@ -183,6 +183,8 @@ pango_cairo_fc_font_install (PangoCairoFont *font,
 		       pango_cairo_fc_font_get_font_face (font));
   cairo_set_font_matrix (cr, &cffont->font_matrix);
   cairo_set_font_options (cr, cffont->options);
+
+  return TRUE;
 }
 
 static void
@@ -267,10 +269,9 @@ pango_cairo_fc_font_get_metrics (PangoFont     *font,
       if (!fcfont->fontmap)
 	return pango_font_metrics_new ();
 
-      info = g_new0 (PangoFcMetricsInfo, 1);
+      info = g_slice_new0 (PangoFcMetricsInfo);
       
-      fcfont->metrics_by_lang = g_slist_prepend (fcfont->metrics_by_lang, 
-						 info);
+      fcfont->metrics_by_lang = g_slist_prepend (fcfont->metrics_by_lang, info);
 	
       info->sample_str = sample_str;
 
@@ -347,13 +348,6 @@ pango_cairo_fc_font_get_glyph (PangoFcFont *font,
   return entry->glyph;
 }
 
-static PangoGlyph
-pango_cairo_fc_font_real_get_unknown_glyph (PangoFcFont *font,
-					    gunichar     wc)
-{
-  return wc | PANGO_CAIRO_UNKNOWN_FLAG;
-}
-
 static void
 pango_cairo_fc_font_glyph_extents_cache_init (PangoCairoFcFont *cffont)
 {
@@ -446,12 +440,7 @@ pango_cairo_fc_font_get_glyph_extents (PangoFont      *font,
   if (cffont->glyph_extents_cache == NULL)
     pango_cairo_fc_font_glyph_extents_cache_init (cffont);
 
-  if (glyph & PANGO_CAIRO_UNKNOWN_FLAG) 
-    {
-      _pango_cairo_get_glyph_extents_missing((PangoCairoFont *)font, glyph, ink_rect, logical_rect);
-      return;
-    }
-  else if (!glyph)
+  if (glyph == PANGO_GLYPH_EMPTY)
     {
       if (ink_rect)
 	*ink_rect = cffont->font_extents;
@@ -459,6 +448,11 @@ pango_cairo_fc_font_get_glyph_extents (PangoFont      *font,
 	*logical_rect = cffont->font_extents;
       return;
     }
+  else if (glyph & PANGO_GLYPH_UNKNOWN_FLAG) 
+    {
+      _pango_cairo_get_glyph_extents_missing((PangoCairoFont *)font, glyph, ink_rect, logical_rect);
+      return;
+    }
 
   entry = pango_cairo_fc_font_get_glyph_extents_cache_entry (cffont, glyph);
 
@@ -515,7 +509,6 @@ pango_cairo_fc_font_class_init (PangoCairoFcFontClass *class)
   fc_font_class->lock_face = pango_cairo_fc_font_lock_face;
   fc_font_class->unlock_face = pango_cairo_fc_font_unlock_face;
   fc_font_class->get_glyph = pango_cairo_fc_font_get_glyph;
-  fc_font_class->get_unknown_glyph = pango_cairo_fc_font_real_get_unknown_glyph;
   fc_font_class->shutdown = pango_cairo_fc_font_shutdown;
 
 #ifdef PROFILE_GLYPH_CACHE
